/* ==================================================== */
/* This source code published as public domain property */ 
/* Developer: Rompo Punyanitya 				   	        */
/*            BCS from RMIT university        	        */
/* Website: www.users.bigpond.net.au/rpunyani/          */
/* Email:   rpunyani@bigpond.net.au                     */
/* ==================================================== */
#include "ScaleInfo.h"
ScaleInfo::ScaleInfo()
:fx_res(0),fy_res(0),fmax_res(0)
{

}
ScaleInfo::ScaleInfo(int64 xres,int64 yres)
{
  SetTo(xres,yres);
}
ScaleInfo::~ScaleInfo()
{

}

void ScaleInfo::SetTo(int64 xres,int64 yres)
{
  fx_res = xres;
  fy_res = yres;

  if (fx_res > fy_res)
  fmax_res = fx_res;
  else
  fmax_res = fy_res;
  
  fx_scale    = fx_res / ConvertSpace::ScreenDPI;
  fy_scale    = fy_res / ConvertSpace::ScreenDPI;
  
  fdraw_scale = fmax_res / ConvertSpace::ScreenDPI;  
}
void ScaleInfo::Unset()
{
  fx_res = fy_res = fmax_res = 0;
  fx_scale = fy_scale = fdraw_scale = 0.0f;
}
// ====================================================================
int64 ScaleInfo::XResolution()const
{
  return fx_res;
}
int64 ScaleInfo::YResolution()const
{
  return fy_res;
}
int64 ScaleInfo::Resolution()const
{
  return fmax_res;
}
// ====================================================================

// ====================================================================
float ScaleInfo::XScale()const
{
  return fx_scale;
}
float ScaleInfo::YScale()const
{
  return fy_scale;
}
float ScaleInfo::DrawScale()const
{
  return fdraw_scale;
}
// ====================================================================

// ====================================================================
BRect ScaleInfo::PrintScaleToDrawScale(BRect rect)
{
  BRect output;
  output.left   = PrintScaleXToDrawScale(rect.left);
  output.right  = PrintScaleXToDrawScale(rect.right);
  output.top    = PrintScaleYToDrawScale(rect.top);
  output.bottom = PrintScaleYToDrawScale(rect.bottom);
  return output;
}
BRect ScaleInfo::PrintScaleToNonScale(BRect rect)
{
  BRect output;
  output.left   = PrintScaleXToNonScale(rect.left);
  output.right  = PrintScaleXToNonScale(rect.right);
  output.top    = PrintScaleYToNonScale(rect.top);
  output.bottom = PrintScaleYToNonScale(rect.bottom);
  return output;
}
   
BRect ScaleInfo::NonScaleToPrintScale(BRect rect)
{
  BRect output;
  output.left   = NonScaleXToPrintScale(rect.left);
  output.right  = NonScaleXToPrintScale(rect.right);
  output.top    = NonScaleYToPrintScale(rect.top);
  output.bottom = NonScaleYToPrintScale(rect.bottom);
  return output;
}
BRect ScaleInfo::NonScaleToDrawScale(BRect rect)
{
  BRect output;
  output.left   = NonScaleXToDrawScale(rect.left);
  output.right  = NonScaleXToDrawScale(rect.right);
  output.top    = NonScaleYToDrawScale(rect.top);
  output.bottom = NonScaleYToDrawScale(rect.bottom);
  return output;
}
    
BRect ScaleInfo::DrawScaleToPrintScale(BRect rect)
{
  BRect output;
  output.left   = DrawScaleXToPrintScale(rect.left);
  output.right  = DrawScaleXToPrintScale(rect.right);
  output.top    = DrawScaleYToPrintScale(rect.top);
  output.bottom = DrawScaleYToPrintScale(rect.bottom);
  return output;
}
BRect ScaleInfo::DrawScaleToNonScale(BRect rect)
{
  BRect output;
  output.left   = DrawScaleXToNonScale(rect.left);
  output.right  = DrawScaleXToNonScale(rect.right);
  output.top    = DrawScaleYToNonScale(rect.top);
  output.bottom = DrawScaleYToNonScale(rect.bottom);
  return output;
}
// ====================================================================

int32 ScaleInfo::PrintScaleXToDrawScale(int32 value)
{
  return (int32) ((value * fdraw_scale) / fx_scale);
}
int32 ScaleInfo::PrintScaleXToNonScale (int32 value)
{
  return (int32) (value / fx_scale);
}
    
int32 ScaleInfo::PrintScaleYToDrawScale(int32 value)
{
  return (int32) ((value * fdraw_scale) / fy_scale);
}
int32 ScaleInfo::PrintScaleYToNonScale (int32 value)
{
  return (int32) (value / fy_scale);
}
    
int32 ScaleInfo::DrawScaleXToPrintScale(int32 value)
{
  return (int32) ((value * fx_scale) / fdraw_scale);
}
int32 ScaleInfo::DrawScaleXToNonScale(int32 value)
{
  return (int32) (value / fdraw_scale);
}
    
int32 ScaleInfo::DrawScaleYToPrintScale(int32 value)
{
  return (int32) ((value * fy_scale) / fdraw_scale);
}
int32 ScaleInfo::DrawScaleYToNonScale(int32 value)
{
  return (int32) (value / fdraw_scale);
}
    
int32 ScaleInfo::NonScaleXToDrawScale (int32 value)
{
  return (int32) (value * fdraw_scale);
}
int32 ScaleInfo::NonScaleXToPrintScale(int32 value)
{
  return (int32) (value * fx_scale);
}
   
int32 ScaleInfo::NonScaleYToDrawScale (int32 value)
{
  return (int32) (value * fdraw_scale);
}
int32 ScaleInfo::NonScaleYToPrintScale(int32 value)
{
  return (int32) (value * fy_scale);
}
